@@ -1,6 +1,7 @@
 # Lancaster, Thu Nov  4 14:44:00 GMT 2004, fresh start from icelfloe
 setClass("Spatial",
-	slots = c(bbox = "matrix", proj4string = "CRS"),
+	#slots = c(bbox = "matrix", proj4string = "CRS"),
+	representation(bbox = "matrix", proj4string = "CRS"),
 	prototype = list(bbox = matrix(rep(NA, 6), 3, 2, 
 		dimnames = list(NULL, c("min","max"))),
 		proj4string = CRS(as.character(NA))), # prototype should not pass validity
