@@ -2,16 +2,25 @@
 	if (returnList == FALSE && is.null(fn))
 		ret = data[sapply(r, function(x) x[1]), , drop=FALSE]
 	else {
-		ret = lapply(1:n, function(x) data[r[[x]],,drop=FALSE]) # splits ret
-		if (returnList == FALSE) { # implies: is.null(fn) is FALSE too
-			ret = do.call(rbind, lapply(ret, 
-				function(x) data.frame(lapply(x, fn, ...))))
+		ret = lapply(1:n, function(x) data[r[[x]],,drop=FALSE]) # list of data.frames
+		if (returnList == FALSE) { # apply fn:
+			ret = do.call(rbind, # rbind each aggregated record
+				lapply(ret, # apply to each data.frame in ret:
+					function(x) {
+						if (nrow(x) == 0)
+							data.frame(lapply(x, function(xx) c(xx, NA)))
+						else
+							data.frame(lapply(x, fn, ...))
+					}
+				)
+			)
 			ret[is.na(ret)] = NA # removes NaN's
 			ret = as.data.frame(ret)
 		} 
 	}
 	ret
 }
+overDF_for_rgeos = .overDF # to be exported, for rgeos only
 
 # we need to invert a list of indexes, i.e.
 # list(c(1,4), c(2,4,5))
@@ -44,10 +53,12 @@
 # overGeomGeomDF in rgeos,
 # ... and overDFGenericST in spacetime.
 overDFGeneric = function(x, y, returnList = FALSE, fn = NULL, ...) {
-	stopifnot(identical(proj4string(x), proj4string(y)))
+	stopifnot(identicalCRS(x, y))
 	r = over(x, geometry(y), returnList = TRUE)
 	ret = .overDF(r, y@data, length(x), returnList, fn, ...)
-	if (! returnList)
+	if (returnList)
+		names(ret) = row.names(x)
+	else
 		row.names(ret) = row.names(x)
 	ret
 }
@@ -55,7 +66,7 @@ overDFGeneric = function(x, y, returnList = FALSE, fn = NULL, ...) {
 setMethod("over",
 	signature(x = "SpatialPoints", y = "SpatialPoints"), 
 		function(x, y, returnList = FALSE, fn = NULL, ...) {
-			stopifnot(identical(proj4string(x),proj4string(y)))
+			stopifnot(identicalCRS(x, y))
 			zd = zerodist2(x, y)
 			if (returnList) {
 				ret = lapply(1:length(x), function(X) integer(0))
@@ -66,34 +77,52 @@ setMethod("over",
 				ret = rep(as.integer(NA), length(x))
 				ret[zd[,1]] = zd[,2]
 			}
+			names(ret) = row.names(x)
 			ret
 		}
 )
 setMethod("over",
 	signature(x = "SpatialPoints", y = "SpatialPolygons"), 
 		function(x, y, returnList = FALSE, fn = NULL, ...) {
-			stopifnot(identical(proj4string(x),proj4string(y)))
+			stopifnot(identicalCRS(x, y))
 			r = pointsInSpatialPolygons(x, y, returnList)
 			if (returnList)
 				r = .invert(r, length(y), length(x))
+			names(r) = row.names(x)
 			r
 		}
 )
 setMethod("over",
 	signature(x = "SpatialPolygons", y = "SpatialPoints"), 
 		function(x, y, returnList = FALSE, fn = NULL, ...) {
-			stopifnot(identical(proj4string(x),proj4string(y)))
+			stopifnot(identicalCRS(x,y))
 			r = pointsInSpatialPolygons(geometry(y), geometry(x), TRUE)
 			if (!returnList)
 				r = sapply(r, function(x) x[1])
+			names(r) = row.names(x)
 			r
 		}
 )
+setMethod("over",
+	signature(x = "SpatialGrid", y = "SpatialPoints"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
+)
 setMethod("over",
 	signature(x = "SpatialGrid", y = "SpatialPolygons"), 
 		function(x, y, returnList = FALSE, fn = NULL, ...)
 			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
 )
+setMethod("over",
+	signature(x = "SpatialGrid", y = "SpatialPixels"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
+)
+setMethod("over",
+	signature(x = "SpatialGrid", y = "SpatialGrid"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
+)
 setMethod("over",
 	signature(x = "SpatialPolygons", y = "SpatialGrid"), 
 		function(x, y, returnList = FALSE, fn = NULL, ...)
@@ -101,17 +130,21 @@ setMethod("over",
 )
 setMethod("over", signature("SpatialPoints", "SpatialGrid"), 
 	function(x, y, returnList = FALSE, fn = NULL, ...) {
-		stopifnot(identical(proj4string(x),proj4string(y)))
+		stopifnot(identicalCRS(x,y))
 		idx = getGridIndex(coordinates(x), y@grid, all.inside = FALSE)
-		.index2list(idx, returnList)
+		r = .index2list(idx, returnList)
+		names(r) = row.names(x)
+		r
 	}
 )
 setMethod("over", signature("SpatialPoints", "SpatialPixels"), 
 	function(x, y, returnList = FALSE, fn = NULL, ...) {
-		stopifnot(identical(proj4string(x),proj4string(y)))
+		stopifnot(identicalCRS(x,y))
 		idx = getGridIndex(coordinates(x), y@grid, all.inside = FALSE)
 		idx = match(idx, y@grid.index)
-		.index2list(idx, returnList)
+		r = .index2list(idx, returnList)
+		names(r) = row.names(x)
+		r
 	}
 )
 setMethod("over",
@@ -120,25 +153,40 @@ setMethod("over",
 setMethod("over",
 	signature(x = "SpatialPoints", y = "SpatialPolygonsDataFrame"), 
 		overDFGeneric)
+setMethod("over",
+	signature(x = "SpatialGrid", y = "SpatialPointsDataFrame"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
+)
 setMethod("over",
 	signature(x = "SpatialGrid", y = "SpatialPolygonsDataFrame"), 
 		function(x, y, returnList = FALSE, fn = NULL, ...)
 			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
 )
+setMethod("over",
+	signature(x = "SpatialGrid", y = "SpatialPixelsDataFrame"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
+)
+setMethod("over",
+	signature(x = "SpatialGrid", y = "SpatialGridDataFrame"), 
+		function(x, y, returnList = FALSE, fn = NULL, ...)
+			over(as(x, "SpatialPoints"), y = y, returnList = returnList, fn = fn, ...)
+)
 setMethod("over",
 	signature(x = "SpatialPolygons", y = "SpatialPointsDataFrame"), 
 		overDFGeneric)
 setMethod("over",
 	signature(x = "SpatialPolygons", y = "SpatialGridDataFrame"), 
 		function(x, y, returnList = FALSE, fn = NULL, ...) {
-			stopifnot(identical(proj4string(x),proj4string(y)))
+			stopifnot(identicalCRS(x,y))
 			over(x, as(y, "SpatialPixelsDataFrame"), returnList = returnList,
 				fn = fn, ...)
 		}
 )
 setMethod("over", signature("SpatialPoints", "SpatialGridDataFrame"), 
 	function(x, y, returnList = FALSE, fn = NULL, ...) {
-		stopifnot(identical(proj4string(x),proj4string(y)))
+		stopifnot(identicalCRS(x,y))
 		idx = over(x, geometry(y))
 		ret = y@data[idx,,drop=FALSE]
 		row.names(ret) = row.names(x)
@@ -147,7 +195,7 @@ setMethod("over", signature("SpatialPoints", "SpatialGridDataFrame"),
 )
 setMethod("over", signature("SpatialPoints", "SpatialPixelsDataFrame"), 
 	function(x, y, returnList = FALSE, fn = NULL, ...) {
-		stopifnot(identical(proj4string(x),proj4string(y)))
+		stopifnot(identicalCRS(x,y))
 		idx = over(x, geometry(y))
 		ret = y@data[idx,,drop=FALSE]
 		row.names(ret) = row.names(x)
@@ -164,11 +212,3 @@ setMethod("over", signature("SpatialPoints", "SpatialPixelsDataFrame"),
 	} else
 		x
 }
-
-aggregate.Spatial = function(x, by, FUN = mean, ...) {
-	by0 = by
-	if (gridded(by))
-		by = as(by, "SpatialPolygons")
-	df = over(by, x, fn = FUN, ...)
-	addAttrToGeom(by0, df, match.ID = FALSE)
-}
